@@ -25,6 +25,7 @@
 
 #include <libvcd/types.h>
 #include <libvcd/files.h>
+#include <cdio/cdio.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -42,10 +43,16 @@ extern "C" {
 #define MAX_VOLUMESET_ID 128
 
 /*!
-  Unvalid LBA, Note: VCD player uses the fact that this is a very high
+  Invalid LBA, Note: VCD player uses the fact that this is a very high
   value.
  */
-#define VCDINFO_NULL_LBA          0xFFFFFFFF
+#define VCDINFO_NULL_LBA          CDIO_INVALID_LBA
+
+/*!
+  Invalid LSN, Note: VCD player uses the fact that this is a very high
+  value.
+ */
+#define VCDINFO_NULL_LSN          VCDINFO_NULL_LBA
 
 /*========== End move somewhere else? ================*/
 
@@ -124,16 +131,6 @@ extern "C" {
     VCDINFO_FILES_VIDEO_INVALID = 8
   } vcdinfo_video_segment_type_t;
   
-  typedef enum {
-    VCDINFO_SOURCE_UNDEF,          /* none of the below, e.g. uninitialized */
-    VCDINFO_SOURCE_AUTO,           /* figure out whether a device or a flie */
-    VCDINFO_SOURCE_BIN,            /* bin disk image; default is 2352 bytes */
-    VCDINFO_SOURCE_CUE,            /* Cue-sheet CD-ROM disk image */
-    VCDINFO_SOURCE_NRG,            /* Nero CD-ROM disk image */
-    VCDINFO_SOURCE_DEVICE,         /* a device like /dev/cdrom */
-    VCDINFO_SOURCE_SECTOR_2336,    /* bin file emulating 2336 bytes/sector */
-  } vcdinfo_source_t;
-  
   /*!
     Used in working with LOT - list of offsets and lid's 
   */
@@ -262,6 +259,13 @@ extern "C" {
   lba_t
   vcdinfo_get_entry_lba(const vcdinfo_obj_t *obj, unsigned int entry_num);
   
+  /*!  Return the starting LSN (logical sector number) for sequence
+    entry_num in obj.  VCDINFO_NULL_LSN is returned if there is no entry.
+    The first entry number is 0.
+  */
+  lsn_t
+  vcdinfo_get_entry_lsn(const vcdinfo_obj_t *obj, unsigned int entry_num);
+  
   /*!  Return the starting MSF (minutes/secs/frames) for sequence
     entry_num in obj.  NULL is returned if there is no entry.
     The first entry number is 0.
@@ -376,6 +380,14 @@ extern "C" {
   lba_t
   vcdinfo_get_seg_lba(const vcdinfo_obj_t *obj, const unsigned int seg_num);
   
+  /*!  Return the starting LSN (logical sector number) for segment
+    entry_num in obj.  VCDINFO_NULL_LBA is returned if there is no entry.
+    
+    Note first seg_num is 0.
+  */
+  lsn_t
+  vcdinfo_get_seg_lsn(const vcdinfo_obj_t *obj, const unsigned int seg_num);
+  
   /*!  Return the starting MSF (minutes/secs/frames) for segment
     entry_num in obj.  NULL is returned if there is no entry.
     
@@ -464,6 +476,20 @@ extern "C" {
   lba_t
   vcdinfo_get_track_lba(const vcdinfo_obj_t *obj, track_t track_num);
   
+  /*!  
+    Return the starting LSN (logical sector number) for track number
+    track_num in obj.  
+    
+    The IS0-9660 filesystem track has number 0. Tracks associated
+    with playable entries numbers start at 1.
+    
+    The "leadout" track is specified either by
+    using track_num LEADOUT_TRACK or the total tracks+1.
+    VCDINFO_NULL_LBA is returned on failure.
+  */
+  lsn_t
+  vcdinfo_get_track_lsn(const vcdinfo_obj_t *obj, track_t track_num);
+  
   /*!  
     Return the starting MSF (minutes/secs/frames) for track number
     track_num in obj.  
@@ -654,7 +680,7 @@ extern "C" {
   */
   vcdinfo_open_return_t
   vcdinfo_open(vcdinfo_obj_t *obj, char *source_name[], 
-	       vcdinfo_source_t source_type, const char access_mode[]);
+	       driver_id_t source_type, const char access_mode[]);
   
   
   /*!
