@@ -1,5 +1,5 @@
 /*
-    $Id: info.c,v 1.1.2.7 2003/04/26 14:37:08 rocky Exp $
+    $Id: info.c,v 1.1.2.9 2003/07/19 20:16:27 rocky Exp $
 
     Copyright (C) 2002,2003 Rocky Bernstein <rocky@panix.com>
 
@@ -56,7 +56,7 @@
 #include "image_fs.h"
 #include "pbc.h"
 
-static const char _rcsid[] = "$Id: info.c,v 1.1.2.7 2003/04/26 14:37:08 rocky Exp $";
+static const char _rcsid[] = "$Id: info.c,v 1.1.2.9 2003/07/19 20:16:27 rocky Exp $";
 
 #define MIN_ENCODED_TRACK_NUM 100
 #define MIN_ENCODED_SEGMENT_NUM 1000
@@ -524,16 +524,16 @@ vcdinfo_get_entry_sect_count (const vcdinfo_obj_t *obj, unsigned int entry_num)
   if (entry_num > entry_count) 
     return 0;
   else {
-    const lba_t this_lba = vcdinfo_get_entry_lba(obj, entry_num);
-    lba_t next_lba;
+    const lsn_t this_lsn = vcdinfo_get_entry_lsn(obj, entry_num);
+    lsn_t next_lsn;
     if (entry_num < entry_count-1) {
       track_t track=vcdinfo_get_track(obj, entry_num);
       track_t next_track=vcdinfo_get_track(obj, entry_num+1);
-      next_lba = vcdinfo_get_entry_lba(obj, entry_num+1);
+      next_lsn = vcdinfo_get_entry_lsn(obj, entry_num+1);
       /* If we've changed tracks, don't include pregap sector between 
          tracks.
        */
-      if (track != next_track) next_lba -= CDIO_PREGAP_SECTORS;
+      if (track != next_track) next_lsn -= CDIO_PREGAP_SECTORS;
     } else {
       /* entry_num == entry_count -1. Or the last entry.
          This is really really ugly. There's probably a better
@@ -548,25 +548,24 @@ vcdinfo_get_entry_sect_count (const vcdinfo_obj_t *obj, unsigned int entry_num)
       track_t track = vcdinfo_get_track(obj, entry_num);
       if (track != VCDINFO_INVALID_TRACK) {
         vcd_image_stat_t statbuf;
-        const lsn_t lsn = cdio_lba_to_lsn(vcdinfo_get_track_lba(obj, track));
+        const lsn_t lsn = vcdinfo_get_track_lsn(obj, track);
 
         /* Try to get the sector count from the ISO 9660 filesystem */
         if (_vcdinfo_find_fs_lsn(obj, &statbuf, lsn)) {
-          const lsn_t next_lsn=lsn + statbuf.secsize;
-          next_lba = cdio_lsn_to_lba(next_lsn);
+          next_lsn = lsn + statbuf.secsize;
         } else {
           /* Failed on ISO 9660 filesystem. Use next track or
              LEADOUT track.  */
-          next_lba = vcdinfo_get_track_lba(obj, track+1);
+          next_lsn = vcdinfo_get_track_lsn(obj, track+1);
         }
-        if (next_lba == VCDINFO_NULL_LBA)
+        if (next_lsn == VCDINFO_NULL_LSN)
           return 0;
       } else {
         /* Something went wrong. Set up size to zero. */
         return 0;
       }
     }
-    return (next_lba - this_lba);
+    return (next_lsn - this_lsn);
   }
 }
 
@@ -587,8 +586,25 @@ vcdinfo_get_entry_msf(const vcdinfo_obj_t *obj, unsigned int entry_num)
 lba_t
 vcdinfo_get_entry_lba(const vcdinfo_obj_t *obj, unsigned int entry_num)
 {
-  const msf_t *msf = vcdinfo_get_entry_msf(obj, entry_num);
-  return (msf != NULL) ? cdio_msf_to_lba(msf) : VCDINFO_NULL_LBA;
+  if ( NULL == obj ) return VCDINFO_NULL_LBA;
+  else {
+    const msf_t *msf = vcdinfo_get_entry_msf(obj, entry_num);
+    msf = vcdinfo_get_entry_msf(obj, entry_num);
+    return (msf != NULL) ? cdio_msf_to_lba(msf) : VCDINFO_NULL_LBA;
+  }
+}
+
+/*!  Return the starting LBA (logical block address) for sequence
+  entry_num in obj.  VCDINFO_NULL_LBA is returned if there is no entry.
+*/
+lsn_t
+vcdinfo_get_entry_lsn(const vcdinfo_obj_t *obj, unsigned int entry_num)
+{
+  if ( NULL == obj ) return VCDINFO_NULL_LBA;
+  else {
+    const msf_t *msf = vcdinfo_get_entry_msf(obj, entry_num);
+    return (msf != NULL) ? cdio_msf_to_lsn(msf) : VCDINFO_NULL_LSN;
+  }
 }
 
 /*!
@@ -805,6 +821,23 @@ vcdinfo_get_seg_lba(const vcdinfo_obj_t *obj, const unsigned int seg_num)
   }
 }
 
+/*!  Return the starting LBA (logical block address) for segment
+  entry_num in obj.  VCDINFO_LSN_NULL is returned if there is no entry.
+
+  Note first seg_num is 0.
+*/
+lsn_t
+vcdinfo_get_seg_lsn(const vcdinfo_obj_t *obj, const unsigned int seg_num)
+{ 
+  if (obj == NULL) return VCDINFO_NULL_LBA;
+  {
+    vcd_image_stat_t *statbuf = 
+      _vcd_list_node_data (_vcd_list_at (obj->segment_list, seg_num));
+    if (statbuf == NULL) return VCDINFO_NULL_LSN;
+    return statbuf->lsn;
+  }
+}
+
 /*!  Return the starting MSF (minutes/secs/frames) for segment
   entry_num in obj.  NULL is returned if there is no entry.
 
@@ -968,17 +1001,33 @@ vcdinfo_get_num_tracks(const vcdinfo_obj_t *obj)
 lba_t 
 vcdinfo_get_track_lba(const vcdinfo_obj_t *obj, track_t track_num)
 {
-  msf_t msf;
-
   if (NULL == obj || NULL == obj->img)
     return VCDINFO_NULL_LBA;
   
 
   /* CdIo tracks start at 1 rather than 0. */
-  if (cdio_get_track_msf(obj->img, track_num+1, &msf))
-    return cdio_msf_to_lba(&msf);
-  return VCDINFO_NULL_LBA;
-  
+  return cdio_get_track_lba(obj->img, track_num+1);
+}
+
+/*!  
+  Return the starting LSN (logical sector number) for track number
+  track_num in obj.  
+
+  The IS0-9660 filesystem track has number 0. Tracks associated
+  with playable entries numbers start at 1.
+
+  The "leadout" track is specified either by
+  using track_num LEADOUT_TRACK or the total tracks+1.
+  VCDINFO_NULL_LBA is returned on failure.
+*/
+lsn_t 
+vcdinfo_get_track_lsn(const vcdinfo_obj_t *obj, track_t track_num)
+{
+  if (NULL == obj || NULL == obj->img)
+    return VCDINFO_NULL_LSN;
+
+  /* CdIo tracks start at 1 rather than 0. */
+  return cdio_get_track_lsn(obj->img, track_num+1);
 }
 
 /*!  
@@ -1030,16 +1079,15 @@ vcdinfo_get_track_sect_count(const vcdinfo_obj_t *obj, const track_t track_num)
   
   {
     vcd_image_stat_t statbuf;
-    const lba_t lba = vcdinfo_get_track_lba(obj, track_num);
-    const lsn_t lsn = cdio_lba_to_lsn(lba);
+    const lsn_t lsn = vcdinfo_get_track_lsn(obj, track_num);
     
     /* Try to get the sector count from the ISO 9660 filesystem */
     if (obj->has_xa && _vcdinfo_find_fs_lsn(obj, &statbuf, lsn)) {
       return statbuf.secsize;
     } else {
-      const lba_t next_lba=vcdinfo_get_track_lba(obj, track_num+1);
+      const lsn_t next_lsn=vcdinfo_get_track_lsn(obj, track_num+1);
       /* Failed on ISO 9660 filesystem. Use track information.  */
-      return next_lba > lba ? next_lba - lba : 0;
+      return next_lsn > lsn ? next_lsn - lsn : 0;
     }
   }
   return 0;
@@ -1420,7 +1468,7 @@ static void
 _vcdinfo_zero(vcdinfo_obj_t *obj)
 {
   memset(obj, 0, sizeof(vcdinfo_obj_t));
-  obj->vcd_type = VCDINFO_SOURCE_UNDEF;
+  obj->vcd_type = VCD_TYPE_INVALID;
   obj->img = NULL;
   obj->lot = NULL;
   obj->source_name = NULL;
@@ -1454,13 +1502,20 @@ vcdinfo_init(vcdinfo_obj_t *obj)
  */
 vcdinfo_open_return_t
 vcdinfo_open(vcdinfo_obj_t *obj, char *source_name[], 
-             vcdinfo_source_t source_type, const char access_mode[])
+             driver_id_t source_type, const char access_mode[])
 {
   CdIo *img;
-  bool null_source = NULL == *source_name;
 
-  if (!vcdinf_open(&img, source_name, source_type, access_mode)) 
+  img = cdio_open(*source_name, DRIVER_UNKNOWN);
+  if (NULL == img) {
     return VCDINFO_OPEN_ERROR;
+  }
+  
+  if (access_mode != NULL) 
+    cdio_set_arg (img, "access-mode", access_mode);
+
+  if (NULL == *source_name) 
+    *source_name = cdio_get_default_device(img);
     
   memset (obj, 0, sizeof (vcdinfo_obj_t));
   obj->img = img;  /* Note we do this after the above wipeout! */
@@ -1494,10 +1549,6 @@ vcdinfo_open(vcdinfo_obj_t *obj, char *source_name[],
     strncpy(obj->source_name, *source_name, len);
   }
 
-  if (null_source) {
-    free(*source_name);
-  }
-
   if (obj->vcd_type == VCD_TYPE_SVCD || obj->vcd_type == VCD_TYPE_HQVCD) {
 
     vcd_image_stat_t statbuf;
