@@ -1,5 +1,5 @@
 /*
-    $Id: info_private.c,v 1.1.2.9 2003/05/18 01:53:50 rocky Exp $
+    $Id: info_private.c,v 1.1.2.11 2003/06/13 03:16:30 rocky Exp $
 
     Copyright (C) 2003 Rocky Bernstein <rocky@panix.com>
 
@@ -61,7 +61,7 @@
 #include "pbc.h"
 #include "xa.h"
 
-static const char _rcsid[] = "$Id: info_private.c,v 1.1.2.9 2003/05/18 01:53:50 rocky Exp $";
+static const char _rcsid[] = "$Id: info_private.c,v 1.1.2.11 2003/06/13 03:16:30 rocky Exp $";
 
 #define BUF_COUNT 16
 #define BUF_SIZE 80
@@ -883,105 +883,6 @@ vcdinf_has_jump_delay (const PsdSelectionListDescriptor *psd)
   return ((0x80 & psd->loop) != 0);
 }
   
-/*!
-  Set up img structure for reading from a particular medium. 
- 
-   source_name is the device or file to use for inspection, and
-   source_type indicates if this is a device or a file.
-   access_mode gives special access options for reading.
-    
-   True is returned if everything went okay; 
- */
-
-bool
-vcdinf_open(/*out*/ CdIo **img, char *source_name[],  
-            vcdinfo_source_t source_type, const char access_mode[]) 
-{
-  char is_sector_2352 = true;
-  bool null_source = NULL == *source_name;
-  
-  if (VCDINFO_SOURCE_AUTO == source_type) {
-    if (null_source) 
-      source_type = VCDINFO_SOURCE_DEVICE;
-    else {
-      struct stat buf;
-      if (0 != stat(*source_name, &buf)) {
-        vcd_error ("Can't stat file %s:", strerror(errno));
-        return false;
-      }
-      if (S_ISBLK(buf.st_mode) || S_ISCHR(buf.st_mode)) {
-        source_type = VCDINFO_SOURCE_DEVICE;
-      } else if (S_ISREG(buf.st_mode)) {
-        /* FIXME: check to see if is a text file. If so, then 
-           set VCDINFO_SOURCE_CUE. */
-        int i=strlen(*source_name)-strlen("bin");
-        if (i > 0
-            && ( (*source_name)[i]   =='n' || (*source_name)[i]   =='N' )
-            && ( (*source_name)[i+1] =='r' || (*source_name)[i+1] =='R' )
-            && ( (*source_name)[i+2] =='g' || (*source_name)[i+2] =='G' ) )
-          source_type = VCDINFO_SOURCE_NRG;
-        else {
-          char *bin_file = cdio_is_cuefile(*source_name);
-          if (NULL != bin_file) {
-            source_type = VCDINFO_SOURCE_CUE;
-            free(bin_file);
-          } else
-            source_type = VCDINFO_SOURCE_BIN;
-        } 
-      } else {
-        vcd_error ("Source file `%s' should either be a block device "
-                   "or a regular file", *source_name);
-        return false;
-      }
-    }
-  }
-  
-  switch (source_type) {
-  case VCDINFO_SOURCE_DEVICE:
-    *img = cdio_open_cd(*source_name);
-    break;
-  case VCDINFO_SOURCE_SECTOR_2336:
-    is_sector_2352 = false;
-    /* Fall through to next case */
-  case VCDINFO_SOURCE_BIN: 
-    {
-      *img = cdio_open_bincue(*source_name);
-      if (NULL != *img) {
-        const char *cue_file = cdio_get_arg(*img, "cue");
-        if (NULL == cue_file) {
-          vcd_error ("Can't find corresponding CUE or TOC file for `%s'", 
-                     *source_name);
-          return false;
-        }
-      }
-      break;
-    }
-  case VCDINFO_SOURCE_CUE:
-    *img = cdio_open_cue(*source_name);
-    break;
-  case VCDINFO_SOURCE_NRG:
-    *img = cdio_open_nrg(*source_name);
-    break;
-  default: 
-    return false;
-  }
-
-  if (NULL == *img) {
-    vcd_error ("Error opening`%s'", *source_name);
-    return false;
-  }
-  
-  if (null_source) {
-    *source_name=cdio_get_default_device(*img);
-  }
-
-  if (access_mode != NULL) 
-    cdio_set_arg (*img, "access-mode", access_mode);
-
-  return NULL != *source_name;
-
-}
-
 
 
 /* 
